@@ -1,5 +1,5 @@
 use anyhow::Result;
-use image::{imageops::FilterType, DynamicImage, GenericImageView};
+use image::{imageops::FilterType, DynamicImage};
 use libc::{
     c_void, ioctl, poll, pollfd, read, tcgetattr, tcsetattr, termios, winsize, ECHO, ICANON,
     POLLIN, STDIN_FILENO, STDOUT_FILENO, TCSANOW, TIOCGWINSZ,
@@ -77,6 +77,12 @@ impl KittyBackend {
     }
 }
 
+impl Default for KittyBackend {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl super::ImageBackend for KittyBackend {
     fn add_image(
         &self,
